@@ -1847,13 +1847,27 @@ void gok_key_set_button_name (GokKey* pKey)
 		break;
 
 	case KEYSTYLE_BRANCHGUIACTIONS:
-	case KEYSTYLE_HYPERLINK:
 	case KEYSTYLE_EDIT:
 	case KEYSTYLE_REPEATNEXT:
 		strcpy (styleButton, "StyleButtonBranchGuiActions");
 		strcpy (styleText, "StyleTextNormal");
 		break;
 		
+	case KEYSTYLE_HYPERLINK:
+		strcpy (styleButton, "StyleButtonHyperlink");
+		strcpy (styleText, "StyleTextHyperlink");
+		break;
+
+	case KEYSTYLE_BRANCHHYPERTEXT:
+		strcpy (styleButton, "StyleButtonHyperText");
+		strcpy (styleText, "StyleTextNormal");
+		break;
+
+	case KEYSTYLE_HTMLACTION:
+		strcpy (styleButton, "StyleButtonHtmlAction");
+		strcpy (styleText, "StyleTextNormal");
+		break;
+
 	case KEYSTYLE_BRANCHALPHABET:
 	case KEYSTYLE_BRANCHTEXT:
 		strcpy (styleButton, "StyleButtonBranchAlphabet");
@@ -2143,6 +2157,7 @@ void gok_key_set_font_size (GokKey* pKey, gint Size)
 	{
 		gok_log_x ("Warning: pango_parse_markup failed in gok_key_set_font_size! String = %s\n", string);
 	}
+	pango_attr_list_unref (pPangoAttrs);
 }
 
 /**
