@@ -225,7 +225,7 @@ gok_wordcomplete_process_unichar (GokWordComplete *complete, gunichar letter)
 {
 	GokWordCompleteClass *klass = GOK_WORDCOMPLETE_GET_CLASS (complete);
 	if (klass->process_unichar)
-		(* klass->process_unichar) (complete, letter);
+		return (* klass->process_unichar) (complete, letter);
 }
 
 /**
@@ -290,7 +290,7 @@ gok_wordcomplete_predict (GokWordComplete *complete, gint num_predictions)
 {
 	GokWordCompleteClass *klass = GOK_WORDCOMPLETE_GET_CLASS (complete);
 	if (klass->predict)
-		(* klass->predict) (complete, num_predictions);
+	    return (* klass->predict) (complete, num_predictions);
 }
 
 /**
